@@ -71,6 +71,7 @@ class Api:
         self.ax_product = api_client("axproduct")
         self.burn_rates = api_client("burnrates")
         self.categories = api_client("categories")
+        self.creativepreview = api_client("creativepreview")
         self.currency_conversion = api_client("currencyconversion")
         self.categories_upload = api_client("categories/upload")
         self.cdn_assets = api_client("cdnassets")
@@ -96,6 +97,7 @@ class Api:
         self.layout_includes = api_client("layoutincludes")
         self.line_items = api_client("lineitems")
         self.line_item_reviews = api_client("lineitems/review")
+        self.livepreview = api_client("livepreview/create")
         self.message_definitions = api_client("messagedefinitions")
         self.network_forecast = api_client("networkforecast")
         self.network_profiles = api_client("networkprofiles")
@@ -131,6 +133,7 @@ class Api:
         self.workspaces = api_client("workspaces")
         self.zipped_assets = api_client("zippedassets")
         self.visitor_profile_fields = api_client("visitorprofilefields")
+        self.coupons = api_client("coupons")
 
 
 class ApiClient:
